@@ -1,5 +1,5 @@
 ## ---- set-lattice ----
-library(lattice)
+library(latticeExtra)
 sides <- list(tck = 0.6, pad1 = 0.75, pad2 = 0.75)
 theme <- list(axis.line = list(alpha = 1, col = 'gray40',
                                fill = "transparent", lty = 1, lwd = 0.5),
@@ -10,7 +10,6 @@ theme <- list(axis.line = list(alpha = 1, col = 'gray40',
               axis.components = list(left = sides, top = sides,
                                      right = sides, bottom = sides),
               fontsize = list(text = 10, points = 6))
-trellis.par.set(theme)
 
 ## ---- binom-dp ----
 binom <- rbind(
@@ -30,6 +29,7 @@ print(binomq, quote=FALSE)
 
 ## ---- binom-gph1 ----
 library(latticeExtra)
+trellis.par.set(theme)
 p <- c(pbinom(q=0:3, size=3, prob=0.5))  # Quantile change points
 p1 <- c(0, p[1], NA, p[1]+0.001, p[2], NA, p[2]+0.001,
         p[3], NA, p[3]+0.001,p[4])
@@ -60,23 +60,23 @@ gph2 <- update(gph2, axis=latticeExtra::axis.grid)
 ## ---- quantile ----
 probrange <- t(cbind("x = Number of heads"=0:3,
                "Interval"=
-c("0, 0.125", ">0.125, 0.5", ">0.5, 0.875", ">0.875, 1.0")))
-xtab <- xtable::xtable(probrange,align=c('l',rep('r',4)))
-colnames(xtab) <- rep("",4)
-print(xtab, type='html', hline.after=NULL)
+c("(0,0.125)", "(>0.125,0.5)", "(>0.5,0.875)", "(>0.875,1.0)")))
+colnames(probrange) <- rep("",4)
+print(probrange, quote=FALSE, right=TRUE)
 
 ## ---- u2q ----
 round(qnorm(c(0.2,0.5,0.8)), 2)
 
 ## ---- gamlss ----
-suppressPackageStartupMessages(library(gamlss))
+PKGgamlss <- suppressPackageStartupMessages(require(gamlss))
 
 ## ---- cfDBI-BB ----
+if(PKGgamlss){
 x <- 0:10
 denBI <- dBI(x, mu=.5, bd=10)
 denDBI2 <- dDBI(x, mu=.5, sigma=2, bd=10)
 denBB2 <- dBB(x, mu=.5, sigma=.125, bd=10)
-par(mar=c(2.6,4.1,2.6,1.6), mgp=c(2.5,.75,0), mfrow=c(1,2))
+oldpar <- par(mar=c(2.6,4.1,2.6,1.6), mgp=c(2.5,.75,0), mfrow=c(1,2))
 x <- 0:10
 cols <- c('gray80',"red","skyblue")
 plot(x, denBI, col='gray80', pch=16, cex=1.25, type=c("b"),
@@ -106,6 +106,8 @@ legend(x="topright",
                            border="gray40", bty="l")
 mtext(side=3, line=0.5, adj=0, cex=1.25,
       expression('B: Binomial vs DBB & DBI: '*Phi==4.75))
+par(oldpar)
+} else message("Package `gamlss` not found")
 
 ## ---- wtd-var ----
 wtd.var <- function(number,w){
@@ -172,24 +174,27 @@ fitVSobs <- function(Number="number", Freq="freq", Fitprob="fitprob",
 }
 
 ## ---- binData ----
-htab <- table(factor(
-  sapply(split(testDriveR::kerrich[,2],
-               rep(1:200,rep(10,200))),sum), levels=0:10),
-  dnn=list("A: Frequency of each of 0 to 10, in 10 tosses"))
+htab <- as.table(matrix(c(0, 5, 7, 22, 37, 43, 48, 28, 8, 2, 0), nrow=1,
+                 dimnames=list("",`A: Frequency of each of 0 to 10, in 10 tosses`=0:10)))
 heads <- data.frame(number=0:10, freq=as.numeric(htab))
 muH <- with(heads, weighted.mean(number, w=freq))
 heads$fitprob <- with(heads, dbinom(number, size=10, prob = muH/10))
-tastab <- table(factor(epiphy::pyrethrum_ray_blight$i, levels=0:6),
-                dnn=list("B: Frequency of each of 0 to 6, in 6 plants"))
-diseased <- data.frame(
-  number=0:6,
-  freq=as.numeric(tastab)
-)
+tastab <- as.table(matrix(c(0, 0, 1, 6, 4, 4, 47), nrow=1,
+                   dimnames=list("",`B: Frequency of each of 0 to 6, in 6 plants`=0:6)))
+diseased <- data.frame(number=0:6, freq=as.numeric(tastab))
 mu <- with(diseased, weighted.mean(number, freq))
 diseased$Binprob <- dbinom(0:6, size=6, prob=mu/6)
 
+## ---- GetbinData ----
+htab <- table(factor(
+  sapply(split(qra::kerrich,
+               rep(1:200,rep(10,200))),sum), levels=0:10),
+  dnn=list("A: Frequency of each of 0 to 10, in 10 tosses"))
+tastab <- table(factor(qra::ray_blight, levels=0:6),
+                dnn=list("B: Frequency of each of 0 to 6, in 6 plants"))
+
 ## ---- binAB ----
-library(lattice)
+trellis.par.set(theme)
 gph1 <- fitVSobs(Number="number", Freq="freq", Fitprob="fitprob", df=heads,
                  digits=2, distribution="binomial", atright=list(at=(1:5)*10,
                                                                  labels=(1:5)/20),
@@ -207,9 +212,9 @@ gph2 <- gph2+latticeExtra::layer(panel.axis(side='left', at=(1:5)*10*62/50,
 ## Sample variance = 1.169751 = 0.4688387*2.495
 
 ## ---- maleFit ----
-muM <- with(fitODBOD::Male_Children,
+muM <- with(qra::malesINfirst12,
             weighted.mean(No_of_Males, w=freq))
-maleFit <- with(fitODBOD::Male_Children,
+maleFit <- with(qra::malesINfirst12,
                 data.frame(number=No_of_Males, freq=freq,
                            fitprob = dbinom(No_of_Males, size=12, prob = muM/12)))
 
@@ -237,7 +242,7 @@ doDBI <- gamlss(cbind(number, 6-number)~1, weights=freq,
                 family=DBI, data=diseased, n.cyc=100, trace=FALSE)
 
 ## ---- cfsim ----
-par(mar=c(2.6,4.1,2.6,1.6), mgp=c(2.5,.75,0), mfrow=c(1,3))
+oldpar <- par(mar=c(2.6,4.1,2.6,1.6), mgp=c(2.5,.75,0), mfrow=c(1,3))
 ## Binomial fits
 rqres.plot(doBI, plot.type='all', type="QQ")
 mtext(side=3, line=0.5, "A: Quantile-quantile", adj=0, cex=1.0)
@@ -245,9 +250,10 @@ res <- rqres.plot(doBI, plot.type='all', type="wp")
 mtext(side=3, line=0.5, "B: Worm plot", adj=0, cex=1.0)
 plot(density(res), xlab="Quantile residuals", main="")
 mtext(side=3, line=0.5, "C: Density plot", adj=0, cex=1.0)
+par(oldpar)
 
 ## ---- cfq2 ----
-par(mar=c(2.6,4.1,2.6,1.6), mgp=c(2.5,.75,0), mfrow=c(1,3))
+oldpar <- par(mar=c(2.6,4.1,2.6,1.6), mgp=c(2.5,.75,0), mfrow=c(1,3))
 ## Betabinomial fits
 rqres.plot(doBB, plot.type='all', type="QQ")
 mtext(side=3, line=0.5, "A: Quantile-quantile", adj=0, cex=0.85)
@@ -255,89 +261,99 @@ res <- rqres.plot(doBB, plot.type='all', type="wp")
 mtext(side=3, line=0.5, "B: Worm plot", adj=0, cex=0.85)
 plot(density(res), xlab="Quantile residuals", main="")
 mtext(side=3, line=0.5, "C: Density plot", adj=0, cex=0.85)
+par(oldpar)
 
 ## ---- cf-AIC ----
-aicStat <- bbmle::AICtab(doBI, doBB, doDBI, mnames=
-                           c("Binomial","Betabinomial","Double binomial"), base=TRUE)
-print(aicStat, type='html', hline.after=NULL, right=TRUE)
+aicStat <- AIC(doBI,doBB,doDBI)
+newnames <- c(doBI="Binomial", doBB="Betabinomial", doDBI="Double binomial")
+rownames(aicStat) <- as.vector(newnames[rownames(aicStat)])
+aicStat[,'dAIC'] <- c(0,diff(aicStat[,'AIC']))
+print(aicStat)
 
-## ---- CBin ----
-## Not used
-doCBin <- bbmle::mle2(fitODBOD::EstMLECorrBin, start=list(p=.8,cov=.05),
-                      data = list(x=diseased$number,freq=diseased$freq))
 
 ## ---- Saxonymales ----
-maleDF <- with(fitODBOD::Male_Children,
-               data.frame(number=No_of_Males, freq=freq))
+maleDF <- qra::malesINfirst12
 ## Numbers of male children, out of 12
 as.table(setNames(maleDF$freq, nm=0:12))
 
-## ---- maleFit ----
-# ## Male children
-# doBI <- gamlss(cbind(number, 12-number)~1, weights=freq,
-#                family=BI, data=maleDF, trace=FALSE)
-# maleDF$binprob <- with(maleDF, dBI(number, bd=12, mu = fv(doBI)[1]))
-#
-# ## ---- alt ----
-# gph <- fitVSobs(Number="number", Freq="freq", Fitprob="binprob", df=maleDF,
-#                 distribution="binomial", size=12,
-#                 atright=list(at=(1:4)*305.75, labels=(1:4)*.05),
-#                 main="B: No. of males out of 12 -- binomial fit")
-
 ## ---- cfMales ----
-doBI <- gamlss(cbind(number, 12-number)~1, weights=freq,
+if(PKGgamlss){
+doBI <- gamlss(cbind(No_of_Males, 12-No_of_Males)~1, weights=freq,
                family=BI, data=maleDF, trace=FALSE)
-doBB <- gamlss(cbind(number, 12-number)~1, weights=freq,
+doBB <- gamlss(cbind(No_of_Males, 12-No_of_Males)~1, weights=freq,
                        family=BB, data=maleDF, trace=FALSE)
-doDBI <- gamlss(cbind(number, 12-number)~1, weights=freq,
+doDBI <- gamlss(cbind(No_of_Males, 12-No_of_Males)~1, weights=freq,
                        family=DBI, data=maleDF, trace=FALSE, n.cyc=100)
-
+}
 
 ## ---- binFitProbs ----
-maleDF$BBfit <- with(maleDF, dBB(number, bd=12,
+if(PKGgamlss){
+maleDF$BBfit <- with(maleDF, dBB(No_of_Males, bd=12,
                                  mu = fv(doBB, 'mu')[1],
                                  sigma=fv(doBB, 'sigma')[1]))
-maleDF$DBIfit <- with(maleDF, dBB(number, bd=12,
+maleDF$DBIfit <- with(maleDF, dBB(No_of_Males, bd=12,
                                   mu = fv(doDBI, 'mu')[1],
                                   sigma=fv(doDBI, 'sigma')[1]))
+} else {
+  maleDF$BBfit <- c(0.000384,0.003692,0.017142,0.050837,0.10723,0.169453,
+    0.205716,0.193319,0.139586,0.075539,0.02909,0.00716,0.000852)
+  maleDF$DBIfit <- c(0.168803,0.079223,0.060521,0.052428,0.048321,0.046371,
+                     0.045942,0.046893,0.049449,0.054383,0.063858,0.085812,0.197996)
+}
 
 ## ---- rqmales ----
-par(mar=c(2.6,4.1,2.6,1.6), mgp=c(2.5,.75,0), mfrow=c(1,2))
+if(PKGgamlss){
+oldpar <- par(mar=c(2.6,4.1,2.6,1.6), mgp=c(2.5,.75,0), mfrow=c(1,2))
 rqres.plot(doBI, plot.type='all', type="wp", main="")
 mtext(side=3, line=0.75, "A: Binomial model", adj=0, cex=1.25)
 rqres.plot(doBB, plot.type='all', type="wp", main="", ylab='')
 mtext(side=3, line=0.75, "B: Betabinomial model", adj=0, cex=1.25)
+par(oldpar)
+} else message("Package `gamlss` is not available")
 
 ## ---- cf-AIC-males ----
+if(PKGgamlss){
 aicStat <- AIC(doBI, doBB, doDBI)
 rownames(aicStat) <-
   c(doBI="Binomial",doBB="Betabinomial",doDBI="Double binomial")[rownames(aicStat)]
 aicStat$dAIC <- with(aicStat, round(AIC-AIC[1],1))
+} else {aicStat <-
+  structure(list(df = c(2, 2, 1), AIC = c(24988.4, 24989.7, 25070.3),
+                 dAIC = c(0, 1.3, 81.9)),
+            row.names = c("Double binomial","Betabinomial", "Binomial"),
+            class = "data.frame")
+}
 aicStat
 
 ## ---- countdata ----
+pkgVGAM <- requireNamespace("VGAM")
+if(pkgVGAM){
 ## Radioactive count data
-rugetab <- with(VGAM::ruge, setNames(as.table(counts), number),
-                dnn=list("A: Numbers of scintillations in 2608 1/8 minute intervals"))
+ruge <- VGAM::ruge
 ## Machinist accidents
-machtab <- with(VGAM::machinists, setNames(as.table(ofreq), accidents),
-                dnn=list("B: Numbers of accidents in three months"))
+machinists <- VGAM::machinists
+} else {
+ruge <- data.frame(counts=c(57,203,383,525,532,408,273,139,45,27,10,4,0,1,1),
+                   number=0:14)
+machinists <- data.frame(accidents=c(0:6,8), ofreq=c(296,74,26,8,4,4,1,1))
+}
 
 ## ---- ruge ----
-rugetab
+## Numbers of scintillations in 2608 1/8 minute intervals
+with(ruge, setNames(counts, number))
 
 ## ---- accs ----
-machtab
+## Numbers of accidents in three months
+with(machinists, setNames(ofreq, accidents))
 
 ## ---- countFits ----
 ## Radioactive count data
-muruge <- with(VGAM::ruge,
-               weighted.mean(number, w=counts))
-rugeFit <- with(VGAM::ruge, data.frame(number=number, freq=counts,
+muruge <- with(ruge, weighted.mean(number, w=counts))
+rugeFit <- with(ruge, data.frame(number=number, freq=counts,
                                        fitprob = dpois(number, lambda = muruge)))
 ## Machinist accidents
-mumach <- with(VGAM::machinists, weighted.mean(accidents, w=ofreq))
-machFit <- with(VGAM::machinists,
+mumach <- with(machinists, weighted.mean(accidents, w=ofreq))
+machFit <- with(machinists,
                 data.frame(number=accidents, freq=ofreq,
                            fitprob = dpois(accidents, lambda = mumach)))
 
@@ -358,6 +374,7 @@ gph2 <- fitVSobs(Number="number", Freq="freq", Fitprob="fitprob", df=machFit,
                  atright=list(at=(0:4)*0.2*414, labels=(0:4)*0.2))
 
 ## ---- cfFits-poiss ----
+if(PKGgamlss){
 dopoiss <- gamlss(number~1, weights=freq,
                   family=PO, data=machFit, trace=FALSE)
 doNBI <- gamlss(number~1, weights=freq,
@@ -371,32 +388,53 @@ doZINBI <- gamlss(number~1, weights=freq,
                 family=ZINBI, data=machFit, trace=FALSE)
 doZIPIG <- gamlss(number~1, weights=freq,
                 family=ZIPIG, data=machFit, trace=FALSE, n.cyc=25)
+}
 
 ## ---- cf-AIC-counts ----
+if(PKGgamlss){
 aicStat <- AIC(dopoiss, doNBI, doPIG, doZIP, doZINBI, doZIPIG)
 aicStat$dAIC <- with(aicStat, round(AIC-AIC[1],1))
+aicStat[,2] <- round(aicStat[,2],1)
+} else
+aicStat <- data.frame(df=c(2,2,3,3,2,1),
+                      AIC=c(767.8, 768.1, 769.6, 770.1, 787.3, 855.8),
+                      dAIC=c(0, 0.2, 1.7, 2.2, 19.4, 88),
+                      row.names=c("doPIG", "doNBI", "doZIPIG", "doZINBI",
+                                    "doZIP", "dopoiss"))
 rownames(aicStat) <-
   c(dopoiss="Poisson",doNBI="Negative binomial",
-                       doPIG="Poisson inverse gamma",
-  doZIP="ZI Poisson",doZINBI="ZI Negative binomial",
-  doZIPIG="ZI Poisson inverse gamma")[rownames(aicStat)]
+    doPIG="Poisson inverse gamma",
+    doZIP="ZI Poisson",doZINBI="ZI Negative binomial",
+    doZIPIG="ZI Poisson inverse gamma")[rownames(aicStat)]
 aicStat
 
 ## ---- wormpois ----
-par(mar=c(2.6,4.1,2.6,1.6), mgp=c(2.5,.75,0), mfrow=c(1,3))
+if(PKGgamlss){
+oldpar <- par(mar=c(2.6,4.1,2.6,1.6), mgp=c(2.5,.75,0), mfrow=c(1,3))
 rqres.plot(dopoiss, plot.type='all', type="wp")
 mtext(side=3, line=1, "A: Worm plot, poisson fit", cex=0.85, adj=0)
 rqres.plot(doZIP, plot.type='all', type="wp")
 mtext(side=3, line=1, "B: Zero-inflated poisson", cex=0.85, adj=0)
 rqres.plot(doNBI, plot.type='all', type="wp", main="Worm plot")
 mtext(side=3, line=1, "C: Negative binomial", cex=0.85, adj=0)
+par(oldpar)
+} else print("Package `gamlss` is not available --- plots are omitted")
 
 ## ---- EstFreqs ----
-mach <- setNames(numeric(9), nm=0:8)
-mach[names(machtab)] <- machtab
-N <- sum(machtab)
+mach <- setNames(numeric(8), nm=c(0:6,8))
+mach[names(mach)] <- machinists$ofreq
+N <- sum(mach)
+if(PKGgamlss){
 NBIprob <- dNBI(0:8, mu=fv(doNBI)[1], sigma=fv(doNBI, 'sigma')[1])
 PIGprob <- dPIG(0:8, mu=fv(doPIG)[1], sigma=fv(doPIG, 'sigma')[1])
 ZIPprob <- dZIP(0:8, mu=fv(doZIP)[1], sigma=fv(doZIP, 'sigma')[1])
 estFreqs <- rbind(NegBin=NBIprob, PIG=PIGprob, ZeroInfPoiss=ZIPprob)*N
-rbind(Frequencies=mach, round(estFreqs,1))
+freqtab <- rbind(Frequencies=c(mach[1:7],0,mach[8]), round(estFreqs,1))
+} else
+  freqtab<- rbind(
+    Frequencies=c(mach[1:7],0,mach[8]),
+    NBIprob=c(296.7, 71, 26.4, 11, 4.8, 2.2, 1, 0.5, 0.2),
+    PIGprob=c(295.1, 76.9, 23.6, 9.3, 4.2, 2.1, 1.1, 0.6, 0.4),
+    ZIPprob=c(296, 62.3, 36.3, 14.1, 4.1, 1, 0.2, 0, 0))
+colnames(freqtab) <- 0:8
+freqtab
